diff lisp/gtk-font-menu.el @ 2527:491f8cf78a9c

[xemacs-hg @ 2005-01-28 02:58:38 by ben] Abstract font-list/color-list font-menu.el, font.el, frame.el, gtk-font-menu.el, minibuf.el, msw-faces.el, msw-font-menu.el, obsolete.el, x-faces.el, x-font-menu.el: list-fonts->font-list. Create color-list. Abstract out x/msw-specific versions and obsolete the x/msw-specific Lisp functions. console-impl.h, objects-gtk.c, objects-msw.c, objects-tty.c, objects-x.c, objects.c: list-fonts->font-list. Create color-list. Abstract out x/msw-specific versions and obsolete the x/msw-specific Lisp functions.
author ben
date Fri, 28 Jan 2005 02:58:52 +0000
parents 13a418960a88
children b4f4e0cc90f1
line wrap: on
line diff
--- a/lisp/gtk-font-menu.el	Fri Jan 28 02:36:28 2005 +0000
+++ b/lisp/gtk-font-menu.el	Fri Jan 28 02:58:52 2005 +0000
@@ -90,7 +90,7 @@
 or if you change your font path, you can call this to re-initialize the menus."
   ;; by Stig@hackvan.com
   ;; #### - this should implement a `menus-only' option, which would
   ;; recalculate the menus from the cache w/o having to do list-fonts again.
   (unless gtk-font-regexp-ascii
     (setq gtk-font-regexp-ascii (if (featurep 'mule)
 				    (declare-fboundp
@@ -102,7 +102,7 @@
 	family size weight entry monospaced-p
 	dev-cache cache families sizes weights)
     (dolist (name (cond ((null debug)	; debugging kludge
-			 (list-fonts "*-*-*-*-*-*-*-*-*-*-*-*-*-*" device))
+			 (font-list "*-*-*-*-*-*-*-*-*-*-*-*-*-*" device))
 			((stringp debug) (split-string debug "\n"))
 			(t debug)))
       (when (and (string-match gtk-font-regexp-ascii name)
@@ -90,7 +90,7 @@
   ;; by Stig@hackvan.com
   ;; #### - this should implement a `menus-only' option, which would
-  ;; recalculate the menus from the cache w/o having to do list-fonts again.
+  ;; recalculate the menus from the cache w/o having to do font-list again.
   (unless gtk-font-regexp-ascii
     (setq gtk-font-regexp-ascii (if (featurep 'mule)